@@ -156,7 +156,7 @@ g_dbus_auth_observer_class_init (GDBusAuthObserverClass *klass)
    * GDBusAuthObserver::authorize-authenticated-peer:
    * @observer: The #GDBusAuthObserver emitting the signal.
    * @stream: A #GIOStream for the #GDBusConnection.
-   * @credentials: (allow-none): Credentials received from the peer or %NULL.
+   * @credentials: (nullable): Credentials received from the peer or %NULL.
    *
    * Emitted to check if a peer that is successfully authenticated
    * is authorized.
@@ -166,7 +166,7 @@ g_dbus_auth_observer_class_init (GDBusAuthObserverClass *klass)
    * Since: 2.26
    */
   signals[AUTHORIZE_AUTHENTICATED_PEER_SIGNAL] =
-    g_signal_new ("authorize-authenticated-peer",
+    g_signal_new (I_("authorize-authenticated-peer"),
                   G_TYPE_DBUS_AUTH_OBSERVER,
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (GDBusAuthObserverClass, authorize_authenticated_peer),
@@ -190,7 +190,7 @@ g_dbus_auth_observer_class_init (GDBusAuthObserverClass *klass)
    * Since: 2.34
    */
   signals[ALLOW_MECHANISM_SIGNAL] =
-    g_signal_new ("allow-mechanism",
+    g_signal_new (I_("allow-mechanism"),
                   G_TYPE_DBUS_AUTH_OBSERVER,
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (GDBusAuthObserverClass, allow_mechanism),
@@ -228,7 +228,7 @@ g_dbus_auth_observer_new (void)
  * g_dbus_auth_observer_authorize_authenticated_peer:
  * @observer: A #GDBusAuthObserver.
  * @stream: A #GIOStream for the #GDBusConnection.
- * @credentials: (allow-none): Credentials received from the peer or %NULL.
+ * @credentials: (nullable): Credentials received from the peer or %NULL.
  *
  * Emits the #GDBusAuthObserver::authorize-authenticated-peer signal on @observer.
  *
