@@ -398,39 +398,27 @@ inet_pton (gint family,
       struct sockaddr_in6 *sin6 = (struct sockaddr_in6 *)&sa;
       gint len = sizeof (sa);
 
-      /* We need to make sure to not pass a string of the form
-       * "IPv4addr:port" or "[IPv6addr]:port" to WSAStringToAddress(),
-       * since it would accept them (returning both the address and the
-       * port), but we only want to accept standalone IP addresses. (In
-       * the IPv6 case, WINE actually only checks for the ']', not the
-       * '[', which is why we do the same here.)
-       */
       if (family != AF_INET && family != AF_INET6)
         {
           WSASetLastError (WSAEAFNOSUPPORT);
           return -1;
         }
-      if (!strchr (addr_string, ':'))
-        {
-          if (WSAStringToAddress ((LPTSTR) addr_string, AF_INET, NULL, (LPSOCKADDR) &sa, &len) == 0)
-            {
-              /* XXX: Figure out when WSAStringToAddress() accepts a IPv4 address but the
-                      numbers-and-dots address is actually not complete.  This code will be
-                      removed once XP/Server 2003 support is dropped... */
-              *(IN_ADDR *) addr = sin->sin_addr;
 
-              return 1;
-            }
-        }
-      if (!strchr (addr_string, ']'))
-        {
-          if (WSAStringToAddress ((LPTSTR) addr_string, AF_INET6, NULL, (LPSOCKADDR) &sa, &len) == 0)
-            {
-              *(IN6_ADDR *) addr = sin6->sin6_addr;
-              return 1;
-            }
-        }
-      return 0;
+      /* WSAStringToAddress() will accept various not-an-IP-address
+       * strings like "127.0.0.1:80", "[1234::5678]:80", "127.1", etc.
+       */
+      if (!g_hostname_is_ip_address (addr_string))
+        return 0;
+
+      if (WSAStringToAddress ((LPTSTR) addr_string, family, NULL, (LPSOCKADDR) &sa, &len) != 0)
+        return 0;
+
+      if (family == AF_INET)
+        *(IN_ADDR *)addr = sin->sin_addr;
+      else
+        *(IN6_ADDR *)addr = sin6->sin6_addr;
+
+      return 1;
     }
 }
 
@@ -446,7 +434,7 @@ inet_ntop (gint family,
   else
     {
       /* Fallback codepath for XP/Server 2003 */
-      DWORD buflen = sizeof (addr_str), addrlen;
+      DWORD buflen = size, addrlen;
       struct sockaddr_storage sa;
       struct sockaddr_in *sin = (struct sockaddr_in *)&sa;
       struct sockaddr_in6 *sin6 = (struct sockaddr_in6 *)&sa;
@@ -488,6 +476,7 @@ inet_ntop (gint family,
  *
  * Returns: a new #GInetAddress corresponding to @string, or %NULL if
  * @string could not be parsed.
+ *     Free the returned object with g_object_unref().
  *
  * Since: 2.22
  */
@@ -525,6 +514,7 @@ g_inet_address_new_from_string (const gchar *string)
  * %G_SOCKET_FAMILY_IPV6.
  *
  * Returns: a new #GInetAddress corresponding to @family and @bytes.
+ *     Free the returned object with g_object_unref().
  *
  * Since: 2.22
  */
@@ -548,6 +538,7 @@ g_inet_address_new_from_bytes (const guint8         *bytes,
  *
  * Returns: a new #GInetAddress corresponding to the loopback address
  * for @family.
+ *     Free the returned object with g_object_unref().
  *
  * Since: 2.22
  */
@@ -575,6 +566,7 @@ g_inet_address_new_loopback (GSocketFamily family)
  *
  * Returns: a new #GInetAddress corresponding to the "any" address
  * for @family.
+ *     Free the returned object with g_object_unref().
  *
  * Since: 2.22
  */
