@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <string.h>
@@ -451,6 +449,8 @@ test_uri_query_info (void)
   GFile *file;
   GFileInfo *info;
   const char *content_type, *mime_type;
+  const char *fs_type;
+  gboolean readonly;
 
   loaded_file = g_file_get_contents (g_test_get_filename (G_TEST_BUILT, "test.gresource", NULL),
                                      &content, &content_size, NULL);
@@ -477,6 +477,16 @@ test_uri_query_info (void)
 
   g_object_unref (info);
 
+  info = g_file_query_filesystem_info (file, "*", NULL, &error);
+  g_assert_no_error (error);
+
+  fs_type = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE);
+  g_assert_cmpstr (fs_type, ==, "resource");
+  readonly = g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_FILESYSTEM_READONLY);
+  g_assert_true (readonly);
+
+  g_object_unref (info);
+
   g_assert_cmpuint  (g_file_hash (file), !=, 0);
 
   g_object_unref (file);
