@@ -89,7 +89,8 @@ typedef gint64 GTimeSpan;
 /**
  * GDateTime:
  *
- * An opaque structure that represents a date and time, including a time zone.
+ * `GDateTime` is an opaque structure whose members
+ * cannot be accessed directly.
  *
  * Since: 2.26
  */
@@ -112,16 +113,10 @@ GDateTime *             g_date_time_new_from_unix_local                 (gint64
 GLIB_AVAILABLE_IN_ALL
 GDateTime *             g_date_time_new_from_unix_utc                   (gint64          t);
 
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-GLIB_DEPRECATED_IN_2_62_FOR(g_date_time_new_from_unix_local)
+GLIB_AVAILABLE_IN_ALL
 GDateTime *             g_date_time_new_from_timeval_local              (const GTimeVal *tv);
-GLIB_DEPRECATED_IN_2_62_FOR(g_date_time_new_from_unix_utc)
+GLIB_AVAILABLE_IN_ALL
 GDateTime *             g_date_time_new_from_timeval_utc                (const GTimeVal *tv);
-G_GNUC_END_IGNORE_DEPRECATIONS
-
-GLIB_AVAILABLE_IN_2_56
-GDateTime *             g_date_time_new_from_iso8601                    (const gchar    *text,
-                                                                         GTimeZone      *default_tz);
 
 GLIB_AVAILABLE_IN_ALL
 GDateTime *             g_date_time_new                                 (GTimeZone      *tz,
@@ -239,16 +234,12 @@ gdouble                 g_date_time_get_seconds                         (GDateTi
 
 GLIB_AVAILABLE_IN_ALL
 gint64                  g_date_time_to_unix                             (GDateTime      *datetime);
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-GLIB_DEPRECATED_IN_2_62_FOR(g_date_time_to_unix)
+GLIB_AVAILABLE_IN_ALL
 gboolean                g_date_time_to_timeval                          (GDateTime      *datetime,
                                                                          GTimeVal       *tv);
-G_GNUC_END_IGNORE_DEPRECATIONS
 
 GLIB_AVAILABLE_IN_ALL
 GTimeSpan               g_date_time_get_utc_offset                      (GDateTime      *datetime);
-GLIB_AVAILABLE_IN_2_58
-GTimeZone *             g_date_time_get_timezone                        (GDateTime      *datetime);
 GLIB_AVAILABLE_IN_ALL
 const gchar *           g_date_time_get_timezone_abbreviation           (GDateTime      *datetime);
 GLIB_AVAILABLE_IN_ALL
@@ -265,8 +256,6 @@ GDateTime *             g_date_time_to_utc                              (GDateTi
 GLIB_AVAILABLE_IN_ALL
 gchar *                 g_date_time_format                              (GDateTime      *datetime,
                                                                          const gchar    *format) G_GNUC_MALLOC;
-GLIB_AVAILABLE_IN_2_62
-gchar *                 g_date_time_format_iso8601                      (GDateTime      *datetime) G_GNUC_MALLOC;
 
 G_END_DECLS
 
